@@ -128,8 +128,16 @@ window.wp = window.wp || {};
 			inlineEditPost.edit( this );
 		});
 
+		// Clone quick edit categories for the bulk editor.
+		var beCategories = $( '#inline-edit fieldset.inline-edit-categories' ).clone();
+
+		// Make "id" attributes globally unique.
+		beCategories.find( '*[id]' ).each( function() {
+			this.id = 'bulk-edit-' + this.id;
+		});
+
 		$('#bulk-edit').find('fieldset:first').after(
-			$('#inline-edit fieldset.inline-edit-categories').clone()
+			beCategories
 		).siblings( 'fieldset:last' ).prepend(
 			$( '#inline-edit .inline-edit-tags-wrap' ).clone()
 		);
@@ -140,7 +148,12 @@ window.wp = window.wp || {};
 		 * Adds onclick events to the apply buttons.
 		 */
 		$('#doaction').on( 'click', function(e){
-			var n;
+			var n,
+				$itemsSelected = $( '#posts-filter .check-column input[type="checkbox"]:checked' );
+
+			if ( $itemsSelected.length < 1 ) {
+				return;
+			}
 
 			t.whichBulkButtonId = $( this ).attr( 'id' );
 			n = t.whichBulkButtonId.substr( 2 );
@@ -178,6 +191,8 @@ window.wp = window.wp || {};
 	 */
 	setBulk : function(){
 		var te = '', type = this.type, c = true;
+		var checkedPosts = $( 'tbody th.check-column input[type="checkbox"]:checked' );
+		var categories = {};
 		this.revert();
 
 		$( '#bulk-edit td' ).attr( 'colspan', $( 'th:visible, td:visible', '.widefat:first thead' ).length );
@@ -217,6 +232,44 @@ window.wp = window.wp || {};
 		// Populate the list of items to bulk edit.
 		$( '#bulk-titles' ).html( '<ul id="bulk-titles-list" role="list">' + te + '</ul>' );
 
+		// Gather up some statistics on which of these checked posts are in which categories.
+		checkedPosts.each( function() {
+			var id      = $( this ).val();
+			var checked = $( '#category_' + id ).text().split( ',' );
+
+			checked.map( function( cid ) {
+				categories[ cid ] || ( categories[ cid ] = 0 );
+				// Just record that this category is checked.
+				categories[ cid ]++;
+			} );
+		} );
+
+		// Compute initial states.
+		$( '.inline-edit-categories input[name="post_category[]"]' ).each( function() {
+			if ( categories[ $( this ).val() ] == checkedPosts.length ) {
+				// If the number of checked categories matches the number of selected posts, then all posts are in this category.
+				$( this ).prop( 'checked', true );
+			} else if ( categories[ $( this ).val() ] > 0 ) {
+				// If the number is less than the number of selected posts, then it's indeterminate.
+				$( this ).prop( 'indeterminate', true );
+				if ( ! $( this ).parent().find( 'input[name="indeterminate_post_category[]"]' ).length ) {
+					// Get the term label text.
+					var label = $( this ).parent().text();
+					// Set indeterminate states for the backend. Add accessible text for indeterminate inputs.
+					$( this ).after( '<input type="hidden" name="indeterminate_post_category[]" value="' + $( this ).val() + '">' ).attr( 'aria-label', label.trim() + ': ' + wp.i18n.__( 'Some selected posts have this category' ) );
+				}
+			}
+		} );
+
+		$( '.inline-edit-categories input[name="post_category[]"]:indeterminate' ).on( 'change', function() {
+			// Remove accessible label text. Remove the indeterminate flags as there was a specific state change.
+			$( this ).removeAttr( 'aria-label' ).parent().find( 'input[name="indeterminate_post_category[]"]' ).remove();
+		} );
+
+		$( '.inline-edit-save button' ).on( 'click', function() {
+			$( '.inline-edit-categories input[name="post_category[]"]' ).prop( 'indeterminate', false );
+		} );
+
 		/**
 		 * Binds on click events to handle the list of items to bulk edit.
 		 *
@@ -228,6 +281,7 @@ window.wp = window.wp || {};
 				$prev = $this.parent().prev().children( '.ntdelbutton' ),
 				$next = $this.parent().next().children( '.ntdelbutton' );
 
+			$( 'input#cb-select-all-1, input#cb-select-all-2' ).prop( 'checked', false );
 			$( 'table.widefat input[value="' + id + '"]' ).prop( 'checked', false );
 			$( '#_' + id ).parent().remove();
 			wp.a11y.speak( wp.i18n.__( 'Item removed.' ), 'assertive' );
@@ -376,9 +430,14 @@ window.wp = window.wp || {};
 		});
 
 		// Handle the post status.
+		var post_date_string = $(':input[name="aa"]').val() + '-' + $(':input[name="mm"]').val() + '-' + $(':input[name="jj"]').val();
+		post_date_string += ' ' + $(':input[name="hh"]').val() + ':' + $(':input[name="mn"]').val() + ':' + $(':input[name="ss"]').val();
+		var post_date = new Date( post_date_string );
 		status = $('._status', rowData).text();
-		if ( 'future' !== status ) {
+		if ( 'future' !== status && Date.now() > post_date ) {
 			$('select[name="_status"] option[value="future"]', editRow).remove();
+		} else {
+			$('select[name="_status"] option[value="publish"]', editRow).remove();
 		}
 
 		pw = $( '.inline-edit-password-input' ).prop( 'disabled', false );
@@ -549,9 +608,9 @@ $( function() { inlineEditPost.init(); } );
 // Show/hide locks on posts.
 $( function() {
 
-	// Set the heartbeat interval to 15 seconds.
+	// Set the heartbeat interval to 10 seconds.
 	if ( typeof wp !== 'undefined' && wp.heartbeat ) {
-		wp.heartbeat.interval( 15 );
+		wp.heartbeat.interval( 10 );
 	}
 }).on( 'heartbeat-tick.wp-check-locked-posts', function( e, data ) {
 	var locked = data['wp-check-locked-posts'] || {};
